summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_type.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/objects/object_type.h')
-rw-r--r--kig/objects/object_type.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kig/objects/object_type.h b/kig/objects/object_type.h
index 54471e46..60b32026 100644
--- a/kig/objects/object_type.h
+++ b/kig/objects/object_type.h
@@ -45,7 +45,7 @@ public:
virtual bool inherits( int type ) const;
- virtual ObjectImp* calc( const Args& parents, const KigDocument& d ) const = 0;
+ virtual ObjectImp* calc( const Args& tqparents, const KigDocument& d ) const = 0;
virtual bool canMove( const ObjectTypeCalcer& ourobj ) const;
virtual bool isFreelyTranslatable( const ObjectTypeCalcer& ourobj ) const;
@@ -57,19 +57,19 @@ public:
const char* fullName() const;
/**
* Supposing that \p parents would be given as parents to
* this type's calc function, this function returns the ObjectImp id
* that \p o should at least have.. ( \p o should be part of \p parents )
*/
- virtual const ObjectImpType* impRequirement( const ObjectImp* o, const Args& parents ) const = 0;
+ virtual const ObjectImpType* impRequirement( const ObjectImp* o, const Args& tqparents ) const = 0;
/**
* Supposing that \p parents would be given as parents to this type's
* calc function, this function returns whether the returned
* ObjectImp will be, by construction, on \p o ( if \p o is a curve ), or
* through \p o ( if \p o is a point ).
*/
- virtual bool isDefinedOnOrThrough( const ObjectImp* o, const Args& parents ) const = 0;
+ virtual bool isDefinedOnOrThrough( const ObjectImp* o, const Args& tqparents ) const = 0;
/**
* returns the ObjectImp id of the ObjectImp's produced by this
@@ -108,7 +108,7 @@ public:
/**
* This is a convenience subclass of ObjectType that a type should
* inherit from if its parents can be specified in an ArgsParser..
*/
class ArgsParserObjectType
: public ObjectType
@@ -119,8 +119,8 @@ protected:
const struct ArgsParser::spec argsspec[],
int n );
public:
- const ObjectImpType* impRequirement( const ObjectImp* o, const Args& parents ) const;
- bool isDefinedOnOrThrough( const ObjectImp* o, const Args& parents ) const;
+ const ObjectImpType* impRequirement( const ObjectImp* o, const Args& tqparents ) const;
+ bool isDefinedOnOrThrough( const ObjectImp* o, const Args& tqparents ) const;
const ArgsParser& argsParser() const;
std::vector<ObjectCalcer*> sortArgs( const std::vector<ObjectCalcer*>& args ) const;
@@ -57,19 +57,19 @@ public:
const char* fullName() const;
/**
- * Supposing that \p parents would be given as parents to
+ * Supposing that \p tqparents would be given as tqparents to
* this type's calc function, this function returns the ObjectImp id
@@ -57,19 +57,19 @@ public:
* this type's calc function, this function returns the ObjectImp id
- * that \p o should at least have.. ( \p o should be part of \p parents )
+ * that \p o should at least have.. ( \p o should be part of \p tqparents )
*/
@@ -57,19 +57,19 @@ public:
/**
- * Supposing that \p parents would be given as parents to this type's
+ * Supposing that \p tqparents would be given as tqparents to this type's
* calc function, this function returns whether the returned
* ObjectImp will be, by construction, on \p o ( if \p o is a curve ), or
@@ -108,7 +108,7 @@ public:
/**
* This is a convenience subclass of ObjectType that a type should
- * inherit from if its parents can be specified in an ArgsParser..
+ * inherit from if its tqparents can be specified in an ArgsParser..
*/
class ArgsParserObjectType